use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007003
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
CheckChangesHasContent
CheckFor
Contributors
CorrectBranch
DROLSKY
DROLSKY's
Dave
Dist
Git
License
PayPal
Plugin
PluginBundle
Pod
Rolsky
Rolsky's
TidyAll
VersionProvider
Weaver
WeaverConfig
Zilla
autarch
drolsky
ini
lib
mailmap
optimizations
perlcriticrc
perltidyrc
tidyall
